@@ -14,7 +14,7 @@ class SPAddonConfig(PluginConfig):
     description = "Add functions used by scanplus GmbH"
 
     # Plugin version
-    version = "0.2.0"
+    version = "0.4.0"
 
     # Plugin author
     author = "Tobias Genannt"
@@ -29,8 +29,5 @@ class SPAddonConfig(PluginConfig):
     # Base URL path. If not set, the plugin name will be used.
     base_url = "sp-addon"
 
-    # Caching config
-    caching_config = {}
-
 
 config = SPAddonConfig
