@@ -1,6 +1,6 @@
 import django_filters
 
-from dcim.filters import DeviceFilterSet
+from dcim.filtersets import DeviceFilterSet
 from dcim.models import RackRole
 
 
